@@ -25,6 +25,7 @@
 #include <X11/extensions/Xrandr.h>
 #include <X11/Xft/Xft.h>
 #include <X11/extensions/xcalibrate.h>
+#include <X11/keysym.h>
 
 #include "h3600_ts.h"
 #include "calibrate.h"
@@ -53,6 +54,8 @@ int error_base, event_base;
 
 int using_xcalibrate;
 
+int moving;
+
 #define CROSSHAIR_SIZE	25
 #define OFFSET 24
 #define WIDTH 3
@@ -172,6 +175,10 @@ handle_events (void)
       
       switch (e.type)
 	{
+	case KeyPress:
+	  if (XKeycodeToKeysym (dpy, e.xkey.keycode, 0) == XK_Escape)
+	    exit (0);
+	  break;
 	case Expose:
 	  if (e.xexpose.window == crosshair_w)
 	    crosshair_expose ();
@@ -200,6 +207,8 @@ crosshair_to (int x, int y)
   if (dx == 0 && dy == 0)
     return;
 
+  moving = True;
+
   r = (double)dy / (double)dx;
 
   if (fabs (r) < 1.0)
@@ -252,6 +261,8 @@ crosshair_to (int x, int y)
   XMoveWindow (dpy, crosshair_w, x, y);
   crosshair_x = x;
   crosshair_y = y;
+
+  moving = False;
 }
 
 void
@@ -285,6 +296,11 @@ set_calibration (calibration *cal)
       if (flag_debug)
 	printf ("constants are: %d %d %d %d %d %d %d\n", cal->a[1], cal->a[2], cal->a[0], cal->a[4], cal->a[5], cal->a[3], cal->a[6]);
       fp = fopen ("/etc/pointercal", "w");
+      if (!fp)
+	{
+	  perror ("/etc/pointercal");
+	  exit (1);
+	}
       fprintf (fp, "%d %d %d %d %d %d %d\n", cal->a[1], cal->a[2], cal->a[0], cal->a[4], cal->a[5], cal->a[3], cal->a[6]);
       fclose (fp); 
       return;
@@ -315,6 +331,12 @@ set_calibration (calibration *cal)
 void
 handle_ts_event (int x, int y, int pressure)
 {
+  if (moving)
+    {
+      /* Ignore any accidental clicks during animation */
+      return;
+    }
+
   if (pressure)
     {
       if (samples < MAX_SAMPLES)
